==> cscec5b-ecxj-impl-3.0.0-20230403.024840-5-sources.jar: com/ejianc/business/ecxj/bean/CompareSupplierTenderEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 中标供应商实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_compare_supplier_tender")
public class CompareSupplierTenderEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="compare_id")
    private Long compareId; // 比选单据主表Id
    @TableField(value="tender_supplier_name")
    private String tenderSupplierName; // 中标供应商名称
    @TableField(value="supplier_credit_code")
    private String supplierCreditCode; // 供应商纳税人编号
    @TableField(value="tender_mny")
    private Long tenderMny; // 中标金额
    @TableField(value="tender_reason")
    private String tenderReason; // 指标原因
    
    
    

    public Long getCompareId() {
        return compareId;
    }

    public void setCompareId(Long compareId) {
        this.compareId = compareId;
    }
    public String getTenderSupplierName() {
        return tenderSupplierName;
    }

    public void setTenderSupplierName(String tenderSupplierName) {
        this.tenderSupplierName = tenderSupplierName;
    }
    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }
    public Long getTenderMny() {
        return tenderMny;
    }

    public void setTenderMny(Long tenderMny) {
        this.tenderMny = tenderMny;
    }
    public String getTenderReason() {
        return tenderReason;
    }

    public void setTenderReason(String tenderReason) {
        this.tenderReason = tenderReason;
    }
    
}

==> cscec5b-ecxj-impl-3.0.0-20231122.020216-54-sources.jar: com/ejianc/business/ecxj/bean/CompareSupplierTenderEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 中标供应商实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_compare_supplier_tender")
public class CompareSupplierTenderEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="compare_id")
    private Long compareId; // 比选单据主表Id
    @TableField(value="tender_supplier_name")
    private String tenderSupplierName; // 中标供应商名称
    @TableField(value="supplier_credit_code")
    private String supplierCreditCode; // 供应商纳税人编号
    @TableField(value="supplier_contract_person")
    private String supplierContractPerson; // 中标供应商联系人
    @TableField(value="supplier_contract_phone")
    private String supplierContractPhone; // 中标供应商联系电话

    @TableField(value="tender_mny")
    private BigDecimal tenderMny; // 中标金额
    @TableField(value="tender_reason")
    private String tenderReason; // 指标原因
    
    
    

    public Long getCompareId() {
        return compareId;
    }

    public void setCompareId(Long compareId) {
        this.compareId = compareId;
    }
    public String getTenderSupplierName() {
        return tenderSupplierName;
    }

    public void setTenderSupplierName(String tenderSupplierName) {
        this.tenderSupplierName = tenderSupplierName;
    }
    public String getSupplierCreditCode() {
        return supplierCreditCode;
    }

    public void setSupplierCreditCode(String supplierCreditCode) {
        this.supplierCreditCode = supplierCreditCode;
    }
    public String getSupplierContractPerson() {
        return supplierContractPerson;
    }

    public void setSupplierContractPerson(String supplierContractPerson) {
        this.supplierContractPerson = supplierContractPerson;
    }
    public String getSupplierContractPhone() {
        return supplierContractPhone;
    }

    public void setSupplierContractPhone(String supplierContractPhone) {
        this.supplierContractPhone = supplierContractPhone;
    }
    public BigDecimal getTenderMny() {
        return tenderMny;
    }

    public void setTenderMny(BigDecimal tenderMny) {
        this.tenderMny = tenderMny;
    }
    public String getTenderReason() {
        return tenderReason;
    }

    public void setTenderReason(String tenderReason) {
        this.tenderReason = tenderReason;
    }
    
}
